#!/bin/sh
# source in configuration and functions

. config.env
. functions.sh

html_start2
validate_user

cat << EOF

EOF

# constants
# name and location for the backup file
date=`date +%y%m%d`
hour=`date +%H`
minutes=`date +%M`
msgfile="tarcmd"
seconds=`du -sm $HOME | gawk '{ print $1 }'`
seconds=$((seconds / 2))

# build filename
tarball=${path}/${prefix}.${date}.${hour}.${minutes}${postfix}

# commands to extract and build tarballs
extract="tar xvzfP"
compress="tar cvzPf"

# Excludecmd not used anymore...
#excludecmd="--exclude=/opt/monitor/etc/host* "
#excludecmd="--exclude=/opt/monitor/share* "
#excludecmd="$excludecmd --exclude=/opt/monitor/sbin*"
#excludecmd="$excludecmd --exclude=/opt/monitor/op5*"
#excludecmd="$excludecmd --exclude=/opt/monitor/bin*"
#excludecmd="$excludecmd --exclude=/opt/monitor/core*"
#excludecmd="$excludecmd --exclude=/opt/monitor/etc/ars/*"

# The files/dirs we want to include in the backup
backup_path="/opt/monitor/etc/*.cfg"

ls /opt/monitor/etc/*.users >& /dev/null
if [ $? == 0 ]; then
	backup_path="$backup_path /opt/monitor/etc/*.users"
fi
ls /opt/monitor/var/*.log  >& /dev/null
if [ $? == 0 ]; then
	backup_path="$backup_path /opt/monitor/var/*.log"
fi
for dir in archives errors traffic; do
	if test -d "/opt/monitor/var/$dir"; then
		backup_path="$backup_path /opt/monitor/var/$dir"
	fi
done


# check if the file we're trying to write to already exists.
# if it does, we refuse, telling the user he can only make one backup
# per minute. This prevents several instances of the script to be run
# simultaneously by different users, thus creating a race condition and
# a kneeling system.
if [ -f $tarball ]; then
cat << EOF
<p><strong><cite>Error: Failed to create backup</cite></strong><br /><br />

The backup file $tarball already exists.<br /><br />
This should only happen if you try to make more than one backups
within one and the same minute, or if somebody else is running the backup
script at the same time. Please hold your horses and try again
in 60 seconds.<br />
Should the problem persist, please contact $support</p>
EOF
html_end2
	exit 0
fi

# ok. We've managed to get this far, so it should be safe to assume all is
# well (since preflight check is done with the first click)
# so we create the tarball and give a link to the admin.
# first some eyecandy though. :)
cat << EOF
<h2>Backup</h2>
<p><strong>Creating tarball from the Monitor home directory.</strong><br />
This will take a few seconds. Please be patient.<br /></p>
EOF

#$compress $tarball $excludecmd $backup_path >& /var/www/html/backup/${msgfile}
#$compress $tarball $backup_path >& /var/www/html/backup/${msgfile}
/opt/monitor/op5/backup/backup $tarball $backup_path >& /var/www/html/backup/${msgfile}
if [ $? -gt 0 ]; then
cat << EOF
<p><strong><cite>
Error: Problem detected during backup creation</cite></strong><br /><br />
For some reason, the backup file '$tarball' could not be properly created.
Should the problem persist, please contact $support, and we will solve this
as soon as possible.<br /><br />
Click <a href="/backup/${msgfile}">here</a> to see the output of the
'tar' command.</p>
EOF
html_end2
	exit 0
fi

# ok. The backup file seems to have gotten through, so we
# stick it under the admins nose in case he wants to grab it.

# strip paths though, since we need it to be in 'backup'
tarball="${tarball##*/}"
msgfile="${msgfile##*/}"

cat << EOF
<p><strong>Backup file <a href="/backup/$tarball">$tarball</a> successfully created.</strong><br /><br />
Click it and choose 'save as' to keep a copy wherever you like.</p>
<p>If you want to see what files are included in this backup, click
<a href="/backup/${msgfile}">here</a>.</p>

EOF
html_end2
#</body></html>
#EOF
